reuse-supported-licenses - reuse 6.1.2 documentation

Skip to content
Back to top
View this page

# reuse-supported-licenses

## Synopsis

reuse supported-licenses [options]

## Description

reuse-supported-licenses generates a list of supported licenses. These are the licenses in the SPDX License List found at https://spdx.org/licenses/. The list may not be up-to-date depending on how recent your installation of reuse is.

The list contains rows with three items each: the SPDX License Identifier, the full name of the license, and an URL to the license.

## Options

-j, --json

  Output the list as JSON.

--help

  Display help and exit.